jenkins-bot has submitted this change and it was merged.

Change subject: E_USER_DEPRECATED undefined prior to php 5.3
......................................................................


E_USER_DEPRECATED undefined prior to php 5.3

follow-up to the backport of Ie1ace158dac1.

p.s. Note, I don't have a php 5.2 install handy to
test this one, but it should fix the issue.

Change-Id: I9d9129def6ecd15719bb69d4f083ef36e6c6b62a
---
M includes/GlobalFunctions.php
1 file changed, 4 insertions(+), 1 deletion(-)

Approvals:
  Demon: Looks good to me, approved
  jenkins-bot: Verified



diff --git a/includes/GlobalFunctions.php b/includes/GlobalFunctions.php
index 4228fa5..67cb3af 100644
--- a/includes/GlobalFunctions.php
+++ b/includes/GlobalFunctions.php
@@ -2212,10 +2212,13 @@
                }
        } else {
                if ( !$suppressCount ) {
                        // E_DEPRECATED is undefined in PHP 5.2
PHP 5.2
                        if( !defined( 'E_DEPRECATED' ) ) {
                                define( 'E_DEPRECATED', 8192 );
                        }
+                       if( !defined( 'E_USER_DEPRECATED' ) ) {
+                               define( 'E_USER_DEPRECATED', 16384 );
+                       }
                        $originalLevel = error_reporting( E_ALL & ~( E_WARNING 
@@ -2212,10 +2212,13 @@
        } else {
                if ( !$suppressCount ) {
-                       // E_DEPRECATED is undefined in PHP 5.2
+                       // E_DEPRECATED and E_USER_DEPRECATED are undefined in 
PHP 5.2
                        if( !defined( 'E_DEPRECATED' ) ) {
| E_NOTICE | E_USER_WARNING | E_USER_NOTICE | E_DEPRECATED | E_USER_DEPRECATED 
| E_STRICT ) );
                }
                ++$suppressCount;

-- 
To view, visit https://gerrit.wikimedia.org/r/59423
To unsubscribe, visit https://gerrit.wikimedia.org/r/settings

Gerrit-MessageType: merged
Gerrit-Change-Id: I9d9129def6ecd15719bb69d4f083ef36e6c6b62a
Gerrit-PatchSet: 2
Gerrit-Project: mediawiki/core
Gerrit-Branch: REL1_19
Gerrit-Owner: Brian Wolff <[email protected]>
Gerrit-Reviewer: Brian Wolff <[email protected]>
Gerrit-Reviewer: CSteipp <[email protected]>
Gerrit-Reviewer: Demon <[email protected]>
Gerrit-Reviewer: jenkins-bot

_______________________________________________
MediaWiki-commits mailing list
[email protected]
https://lists.wikimedia.org/mailman/listinfo/mediawiki-commits

Reply via email to